This SASA module contains methods for the calculation of the solvent accessible surface area (SASA) of proteins using either the fast algorithm by Hasel et al. that is described in the first paper cited below the LCPO algorithm that is described in the second paper. This module can be used to include the SASA as a collective variable in metadynamics simulations, and also for implicit solvent simulations as described in the last three papers cited below.

## Installation 

This module is not installed by default. Add `--enable-modules=sasa` to your './configure' command when building PLUMED to enable these features.
